@@ -1,9 +1,11 @@
 from typing import Type
-from .python import Python
 from .php import PHP
+from .multi import Multi
+from .python import Python
 from .javascript import Javascript
 
 import os
+from typing import Union
 
 class LanguageParser(object):
     '''
@@ -12,17 +14,20 @@ class LanguageParser(object):
     to use
     '''
 
-    EXT_TO_LANG = {'.py': Python, '.php': PHP, '.js': Javascript}
+    EXT_TO_LANG = {'.py': Python, '.php': PHP, '.js': Javascript,
+                   '.jsx': Javascript, '.ts': Javascript, '.tsx': Javascript}
 
     def __init__(self):
         pass
     
     @staticmethod
-    def detect_language(filename: str, runtime: str)-> Type[Python]|Type[PHP]|Type[Javascript]:
+    def detect_language(filename: str, runtime: str)-> Union[Python, PHP, Javascript]:
+        if runtime == 'multi':
+            return Multi(filename, runtime)
         return LanguageParser.EXT_TO_LANG[os.path.splitext(filename)[1].lower()](filename, runtime)
 
     @staticmethod
     def run_file(filename, runtime):
         lang_parser = LanguageParser.detect_language(filename, runtime)
         lang_parser.is_file = True
-        lang_parser.anon_function()
\ No newline at end of file
+        lang_parser.anon_function()
